Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Key ¶
Will represent a key, will be able to get the code and the string value from it. By default 2 keys are written, one when the key pressed, and one when released, therefore make sure to check the status with IsPressed or IsReleased
func (*Key) IsBackSpace ¶
func (*Key) IsReleased ¶
type KeyboardFile ¶
type KeyboardFile struct {
// contains filtered or unexported fields
}
func New ¶
func New(keyboardFilePath string) (*KeyboardFile, error)
Will create a new Keyboard listener
func (*KeyboardFile) Close ¶
func (k *KeyboardFile) Close() error
Click to show internal directories.
Click to hide internal directories.